EnviedField class final

Annotation used to specify an environment variable that should be generated from the .env file specified in the Envied path parameter.

Constructors

EnviedField({String? varName, bool? obfuscate, Object? defaultValue, bool? environment, bool? optional, bool? useConstantCase, bool? interpolate, bool? rawString, int? randomSeed})
const

Properties

defaultValue Object?
Allows this default value to be used if the environment variable is not set. The default value to use if the environment variable is not specified in the .env file. The default value not to use if the environment variable is specified in the .env file. The default value must be a String, bool or a num.
final
environment bool?
When set to true, the value set in the .env file will not be used as the ultimate value but will instead be used as the key and the ultimate value will be read from Platform.environment.
final
hashCode int
The hash code for this object.
no setterinherited
interpolate bool?
Whether to use the interpolated value for the field. If interpolate is true, the value will be interpolated with the environment variables.
final
obfuscate bool?
Allows this values to be encrypted using a random generated key that is then XOR'd with the encrypted value when being accessed the first time. Please note that the values can not be offered with the const qualifier, but only with final. Overrides the per-class obfuscate option!
final
optional bool?
Allows this field to be optional when the type is nullable.
final
randomSeed int?
A seed can be provided if the obfuscation randomness needs to remain reproducible across builds. Note: This will make the Random instance non-secure!
final
rawString bool?
Whether to use the raw string format for the value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useConstantCase bool?
Whether to convert the field name to CONSTANT_CASE.
final
varName String?
The environment variable name specified in the .env file to generate for the annotated variable
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited